@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
 """
+reset_db command
+
 originally from http://www.djangosnippets.org/snippets/828/ by dnordberg
 """
+import os
 import logging
 
 from django.conf import settings
@@ -55,7 +58,7 @@ class Command(BaseCommand):
     @signalcommand
     def handle(self, *args, **options):
         """
-        Resets the database for this project.
+        Reset the database for this project.
 
         Note: Transaction wrappers are in reverse as a work around for
         autocommit, anybody know how to do this the right way?
@@ -65,7 +68,7 @@ class Command(BaseCommand):
         if dbinfo is None:
             raise CommandError("Unknown database router %s" % router)
 
-        engine = dbinfo.get('ENGINE').split('.')[-1]
+        engine = dbinfo.get('ENGINE')
 
         user = password = database_name = database_host = database_port = ''
         if engine == 'mysql':
@@ -98,15 +101,28 @@ Type 'yes' to continue, or 'no' to cancel: """ % (database_name,))
             print("Reset cancelled.")
             return
 
-        if engine in ('sqlite3', 'spatialite'):
-            import os
+        SQLITE_ENGINES = getattr(settings, 'DJANGO_EXTENSIONS_RESET_DB_SQLITE_ENGINES', (
+            'django.db.backends.sqlite3',
+            'django.db.backends.spatialite',
+        ))
+        MYSQL_ENGINES = getattr(settings, 'DJANGO_EXTENSIONS_RESET_DB_MYSQL_ENGINES', (
+            'django.db.backends.mysql',
+        ))
+        POSTGRESQL_ENGINES = getattr(settings, 'DJANGO_EXTENSIONS_RESET_DB_POSTGRESQL_ENGINES', (
+            'django.db.backends.postgresql',
+            'django.db.backends.postgresql_psycopg2',
+            'django.db.backends.postgis',
+            'psqlextra.backend',
+        ))
+
+        if engine in SQLITE_ENGINES:
             try:
-                logging.info("Unlinking %s database" % engine)
+                logging.info("Unlinking %s database", engine)
                 os.unlink(database_name)
             except OSError:
                 pass
 
-        elif engine in ('mysql',):
+        elif engine in MYSQL_ENGINES:
             import MySQLdb as Database
             kwargs = {
                 'user': user,
@@ -124,12 +140,12 @@ Type 'yes' to continue, or 'no' to cancel: """ % (database_name,))
             drop_query = 'DROP DATABASE IF EXISTS `%s`' % database_name
             utf8_support = '' if options['no_utf8_support'] else 'CHARACTER SET utf8'
             create_query = 'CREATE DATABASE `%s` %s' % (database_name, utf8_support)
-            logging.info('Executing... "' + drop_query + '"')
+            logging.info('Executing... "%s"', drop_query)
             connection.query(drop_query)
-            logging.info('Executing... "' + create_query + '"')
+            logging.info('Executing... "%s"', create_query)
             connection.query(create_query.strip())
 
-        elif engine in ('postgresql', 'postgresql_psycopg2', 'postgis'):
+        elif engine in POSTGRESQL_ENGINES:
             import psycopg2 as Database  # NOQA
 
             conn_params = {'database': 'template1'}
@@ -152,18 +168,18 @@ Type 'yes' to continue, or 'no' to cancel: """ % (database_name,))
                     FROM pg_stat_activity
                     WHERE pg_stat_activity.datname = '%s';
                 """ % database_name
-                logging.info('Executing... "' + close_sessions_query.strip() + '"')
+                logging.info('Executing... "%s"', close_sessions_query.strip())
                 try:
                     cursor.execute(close_sessions_query)
                 except Database.ProgrammingError as e:
-                    logging.exception("Error: %s" % str(e))
+                    logging.exception("Error: %s", str(e))
 
             drop_query = "DROP DATABASE \"%s\";" % database_name
-            logging.info('Executing... "' + drop_query + '"')
+            logging.info('Executing... "%s"', drop_query)
             try:
                 cursor.execute(drop_query)
             except Database.ProgrammingError as e:
-                logging.exception("Error: %s" % str(e))
+                logging.exception("Error: %s", str(e))
 
             create_query = "CREATE DATABASE \"%s\"" % database_name
             if owner:
@@ -175,7 +191,7 @@ Type 'yes' to continue, or 'no' to cancel: """ % (database_name,))
             else:
                 create_query += ';'
 
-            logging.info('Executing... "' + create_query + '"')
+            logging.info('Executing... "%s"', create_query)
             cursor.execute(create_query)
 
         else:
